@@ -21,6 +21,7 @@ import random
 import six
 import tensorflow as tf
 from absl import logging
+
 from tf_transformers.data import separate_x_y
 
 logging.set_verbosity("INFO")
@@ -149,7 +150,7 @@ class TFWriter(object):
 
         else:
             n_files = 1
-            self.all_files = ["{}_{}_{}_{}".format(file_name, i, tag, n_files) for i in range(n_files)]
+            self.all_files = ["{}_{}_{}_{}.tfrecord".format(file_name, i, tag, n_files) for i in range(n_files)]
             if overwrite is False:
                 is_check(self.all_files)
             self.all_writer = [tf.io.TFRecordWriter(file_) for file_ in self.all_files]
@@ -249,30 +250,38 @@ class TFWriter(object):
             features[key] = self.schema_writer_fn[key](value)
         example_proto = tf.train.Example(features=tf.train.Features(feature=features))
 
-        if self.shuffle:
-            index = random.choice(range(len(self.all_writer)))
-            the_writer = self.all_writer[index]
-            the_writer.write(example_proto.SerializeToString())
-            self.examples_per_record[self.all_files[index]] += 1
-            self.global_counter += 1
+        if self.tag == "train":
+            if self.shuffle:
+                index = random.choice(range(len(self.all_writer)))
+                the_writer = self.all_writer[index]
+                the_writer.write(example_proto.SerializeToString())
+                self.examples_per_record[self.all_files[index]] += 1
+                self.global_counter += 1
+            else:
+
+                # If global counter(no of individual records processed)
+                # exceeds max_files_per_record then increment self.current_writer
+                if self.global_counter > (self.current_writer + 1) * self.max_files_per_record:
+                    self.current_writer += 1
+                    self.current_file_name = "{}_{}_{}.tfrecord".format(self.file_name, self.tag, self.current_writer)
+                    self.examples_per_record[self.current_file_name] = 0
+                    self.current_file = tf.io.TFRecordWriter(self.current_file_name)
+                    self.temp_writers.append(self.current_file)
+
+                the_writer = self.current_file
+                the_writer.write(example_proto.SerializeToString())
+                self.examples_per_record[self.current_file_name] += 1
+                self.global_counter += 1
+
+            if self.global_counter % self.verbose_counter == 0:
+                logging.info("Wrote {} tfrecods".format(self.global_counter))
         else:
-
-            # If global counter(no of individual records processed)
-            # exceeds max_files_per_record then increment self.current_writer
-            if self.global_counter > (self.current_writer + 1) * self.max_files_per_record:
-                self.current_writer += 1
-                self.current_file_name = "{}_{}_{}.tfrecord".format(self.file_name, self.tag, self.current_writer)
-                self.examples_per_record[self.current_file_name] = 0
-                self.current_file = tf.io.TFRecordWriter(self.current_file_name)
-                self.temp_writers.append(self.current_file)
-
-            the_writer = self.current_file
+            the_writer = self.all_writer[0]
             the_writer.write(example_proto.SerializeToString())
-            self.examples_per_record[self.current_file_name] += 1
             self.global_counter += 1
 
-        if self.global_counter % self.verbose_counter == 0:
-            logging.info("Wrote {} tfrecods".format(self.global_counter))
+            if self.global_counter % self.verbose_counter == 0:
+                logging.info("Wrote {} tfrecods".format(self.global_counter))
 
 
 class TFReader(object):
@@ -349,26 +358,67 @@ class TFReader(object):
 
         return parse_dict
 
-    def auto_batch_for_training(self,
-                            tf_dataset, batch_size, x_keys=None, y_keys=None, shuffle=False, drop_remainder=False, shuffle_buffer_size=10000, prefetch_buffer_size=100):
+    def auto_batch(
+        self,
+        tf_dataset,
+        batch_size,
+        padded_values=None,
+        padded_shapes=None,
+        x_keys=None,
+        y_keys=None,
+        shuffle=False,
+        drop_remainder=False,
+        shuffle_buffer_size=10000,
+        prefetch_buffer_size=100,
+    ):
+        """Auto Batching
+
+        Args:
+            tf_dataset : TF dataset
+            x_keys (optional): List of key names. We will filter based on this.
+            y_keys (optional): List of key names.
+            shuffle (bool, optional): [description]. Defaults to False.
+            shuffle_buffer_size (int, optional): [description]. Defaults to 10000.
+
+        Returns:
+            batched tf dataset
+        """
         element_spec = tf_dataset.element_spec
-        padded_values = {}
-        for k,v in element_spec.items():
-            padded_values[k] = tf.constant(0, dtype=v.dtype)
-        dataset = tf_dataset.padded_batch(padding_values=padded_values,
-                                            batch_size=batch_size,
-                                            drop_remainder=drop_remainder)
+        _padded_values = {}
+        if not padded_values:
+            padded_values = {}
+        # sometimes we might have to have sme custom values other than 0
+        for k, v in element_spec.items():
+            if k in padded_values:
+                value = padded_values[k]
+                _padded_values[k] = tf.constant(value, dtype=value.dtype)
+            else:
+                _padded_values[k] = tf.constant(0, dtype=v.dtype)
+        dataset = tf_dataset.padded_batch(
+            padding_values=_padded_values,
+            padded_shapes=padded_shapes,
+            batch_size=batch_size,
+            drop_remainder=drop_remainder,
+        )
+        # fmt: off
         if x_keys and y_keys:
-            dataset = dataset.map(lambda x: separate_x_y(x, x_keys, y_keys),
-                                num_parallel_calls=tf.data.experimental.AUTOTUNE)
+            dataset = dataset.map(lambda x: separate_x_y(x, x_keys, y_keys), num_parallel_calls=tf.data.experimental.AUTOTUNE)  # noqa
+        # fmt: on
         if shuffle:
-            dataset = dataset.shuffle(
-                shuffle_buffer_size, seed=None, reshuffle_each_iteration=True
-            )
-        dataset = dataset.prefetch(prefetch_buffer_size)
+            dataset = dataset.shuffle(shuffle_buffer_size, seed=None, reshuffle_each_iteration=True)
+        dataset = dataset.prefetch(tf.data.experimental.AUTOTUNE)
         return dataset
 
-    def read_record(self, keys=[], auto_batch = False, **kwargs):
+    def read_record(self, keys=[], auto_batch=False, **kwargs):
+        """Read TF records
+
+        Args:
+            keys (list, optional): List of keys to read from the records
+            auto_batch (bool, optional): Whethe to auto batch data
+
+        Returns:
+            [type]: [description]
+        """
         dataset = tf.data.Dataset.list_files(self.tfrecord_files, shuffle=self.shuffle_files)
         dataset = dataset.interleave(
             tf.data.TFRecordDataset,
@@ -383,7 +433,7 @@ class TFReader(object):
         # Using `ignore_errors()` will drop the element that causes an error.
         dataset = dataset.apply(tf.data.experimental.ignore_errors())  # ==> {1., 0.5, 0.2}
         if auto_batch:
-            dataset = self.auto_batch_for_training(dataset, **kwargs)
+            dataset = self.auto_batch(dataset, **kwargs)
         return dataset
 
 
