@@ -51,6 +51,7 @@ class T5Attention(LegacyLayer):
         bias_constraint=None,
         use_bias=True,
         name="attention",
+        is_cross_attention=False,
         **kwargs,
     ):
         """
@@ -85,15 +86,25 @@ class T5Attention(LegacyLayer):
         self._kernel_constraint = tf.keras.constraints.get(kernel_constraint)
         self._bias_constraint = tf.keras.constraints.get(bias_constraint)
         self._use_bias = use_bias
+        self._cross_layer = is_cross_attention
 
         if self._create_positonal_embedding:
             # self._relative_embedding = tf.keras.layers.Embedding(
             #             self._positional_buckets, self._num_heads, name="relative_attention_bias")
-            self._relative_embedding = OnDeviceEmbedding(
-                self._positional_buckets,
-                self._num_heads,
-                name="relative_attention_bias",
-            )
+
+            if self._cross_layer is True:
+                self._relative_embedding = OnDeviceEmbedding(
+                    self._positional_buckets,
+                    self._num_heads,
+                    trainable=False,
+                    name="relative_attention_bias",
+                )
+            else:
+                self._relative_embedding = OnDeviceEmbedding(
+                    self._positional_buckets,
+                    self._num_heads,
+                    name="relative_attention_bias",
+                )
 
         self._query_dense = dense_einsum.DenseEinsum(
             output_shape=(self._num_heads, self._head_size),
