@@ -6,7 +6,7 @@ import tensorflow as tf
 
 from tf_transformers.core import LegacyLayer
 from tf_transformers.layers import dense_einsum
-from tf_transformers.layers.attention import MultiHeadAttention
+from tf_transformers.layers.attention import BigBirdAttention, BlockMultiHeadAttention, MultiHeadAttention
 
 
 class TransformerBERT(LegacyLayer):
@@ -25,6 +25,7 @@ class TransformerBERT(LegacyLayer):
         num_attention_heads,
         intermediate_size,
         intermediate_activation,
+        attention_head_size=None,
         attention_cfg=None,
         dropout_rate=0.0,
         attention_dropout_rate=0.0,
@@ -40,6 +41,9 @@ class TransformerBERT(LegacyLayer):
         share_attention_layers=True,
         layer_norm_epsilon=None,
         cross_attention_inside_encoder=False,
+        attention_type="full_attention",  # ['full_attention', 'block_attention']
+        block_size=64,
+        num_rand_blocks=3,
         name="transformer",
         **kwargs,
     ):
@@ -85,6 +89,10 @@ class TransformerBERT(LegacyLayer):
         self._layer_norm_epsilon = layer_norm_epsilon
         self._share_attention_layers = share_attention_layers
         self._cross_attention_inside_encoder = cross_attention_inside_encoder
+        self._attention_type = attention_type
+        self._attention_head_size = attention_head_size
+        self._num_rand_blocks = num_rand_blocks
+        self._from_block_size = self._to_block_size = block_size
 
         if self._is_decoder is None:
             raise ValueError(
@@ -103,28 +111,69 @@ class TransformerBERT(LegacyLayer):
             raise ValueError("TransformerBERT expects a three-dimensional input of " "shape [batch, sequence, width].")
         batch_size, sequence_length, hidden_size = input_tensor_shape
 
-        if hidden_size % self._num_heads != 0:
-            raise ValueError(
-                "The input size (%d) is not a multiple of the number of attention "
-                "heads (%d)" % (hidden_size, self._num_heads)
-            )
-        self._attention_head_size = int(hidden_size // self._num_heads)
+        if not self._attention_head_size:
+            if hidden_size % self._num_heads != 0:
+                raise ValueError(
+                    "The input size (%d) is not a multiple of the number of attention "
+                    "heads (%d)" % (hidden_size, self._num_heads)
+                )
+            self._attention_head_size = int(hidden_size // self._num_heads)
 
-        self._attention_layer = MultiHeadAttention(
-            num_heads=self._num_heads,
-            head_size=self._attention_head_size,
-            dropout_rate=self._attention_dropout_rate,
-            kernel_initializer=self._kernel_initializer,
-            bias_initializer=self._bias_initializer,
-            kernel_regularizer=self._kernel_regularizer,
-            bias_regularizer=self._bias_regularizer,
-            activity_regularizer=self._activity_regularizer,
-            kernel_constraint=self._kernel_constraint,
-            bias_constraint=self._bias_constraint,
-            is_training=self.is_training,
-            use_dropout=self.use_dropout,
-            name="self_attention",
-        )
+        if self._attention_type == "full_attention":
+
+            self._attention_layer = MultiHeadAttention(
+                num_heads=self._num_heads,
+                head_size=self._attention_head_size,
+                dropout_rate=self._attention_dropout_rate,
+                kernel_initializer=self._kernel_initializer,
+                bias_initializer=self._bias_initializer,
+                kernel_regularizer=self._kernel_regularizer,
+                bias_regularizer=self._bias_regularizer,
+                activity_regularizer=self._activity_regularizer,
+                kernel_constraint=self._kernel_constraint,
+                bias_constraint=self._bias_constraint,
+                is_training=self.is_training,
+                use_dropout=self.use_dropout,
+                name="self_attention",
+            )
+
+        if self._attention_type == "block_attention":
+
+            self._attention_layer = BlockMultiHeadAttention(
+                num_heads=self._num_heads,
+                head_size=self._attention_head_size,
+                dropout_rate=self._attention_dropout_rate,
+                kernel_initializer=self._kernel_initializer,
+                bias_initializer=self._bias_initializer,
+                kernel_regularizer=self._kernel_regularizer,
+                bias_regularizer=self._bias_regularizer,
+                activity_regularizer=self._activity_regularizer,
+                kernel_constraint=self._kernel_constraint,
+                bias_constraint=self._bias_constraint,
+                is_training=self.is_training,
+                use_dropout=self.use_dropout,
+                name="self_attention",
+            )
+
+        if self._attention_type == "bigbird":
+            self._attention_layer = BigBirdAttention(
+                num_heads=self._num_heads,
+                head_size=self._attention_head_size,
+                num_rand_blocks=self._num_rand_blocks,
+                from_block_size=self._from_block_size,
+                to_block_size=self._to_block_size,
+                dropout_rate=self._attention_dropout_rate,
+                kernel_initializer=self._kernel_initializer,
+                bias_initializer=self._bias_initializer,
+                kernel_regularizer=self._kernel_regularizer,
+                bias_regularizer=self._bias_regularizer,
+                activity_regularizer=self._activity_regularizer,
+                kernel_constraint=self._kernel_constraint,
+                bias_constraint=self._bias_constraint,
+                is_training=self.is_training,
+                use_dropout=self.use_dropout,
+                name="self_attention",
+            )
 
         self._attention_output_dense = dense_einsum.DenseEinsum(
             output_shape=hidden_size,
@@ -291,6 +340,7 @@ class TransformerBERT(LegacyLayer):
         """
         input_tensor, attention_mask = inputs
 
+        # For bigbird (attention_mask is input_mask) 2D
         # No pre norm for GPT2
         # input_tensor_norm = self._pre_attention_norm(input_tensor)
         attention_inputs = [input_tensor, input_tensor]
@@ -318,11 +368,11 @@ class TransformerBERT(LegacyLayer):
         # Use float32 in keras layer norm for numeric stability
         if self.dtype == tf.float16:
             layer_output = tf.cast(layer_output, tf.float32)
-        layer_output = self._output_layer_norm(layer_output + attention_output)
+            attention_output = tf.cast(attention_output, dtype=tf.float32)
+        layer_output = self._output_layer_norm(tf.cast(layer_output, dtype=tf.float32) + attention_output)
         return layer_output, key, value
 
-    def call_cross_attention_in_encoder(self,
-            inputs, mode, cache_key=None, cache_value=None):
+    def call_cross_attention_in_encoder(self, inputs, mode, cache_key=None, cache_value=None):
         """
         inputs: dict keys:
                 if self.is_training:
@@ -361,14 +411,18 @@ class TransformerBERT(LegacyLayer):
         (
             input_tensor,
             attention_mask,
-            decoder_encoder_mask, # None when  mode == 'encoder'
-            encoder_attention_output, # None when mode == 'encoder'
+            decoder_encoder_mask,  # None when  mode == 'encoder'
+            encoder_attention_output,  # None when mode == 'encoder'
         ) = inputs
-        if mode == 'encoder':
+        if mode == "encoder":
             encoder_attention_output, _, _ = calculate_self_attention(input_tensor, attention_mask)
             return encoder_attention_output, _, _
-        if mode == 'decoder':
-            decoder_attention_output, key, value,  = calculate_self_attention(input_tensor, attention_mask)
+        if mode == "decoder":
+            (
+                decoder_attention_output,
+                key,
+                value,
+            ) = calculate_self_attention(input_tensor, attention_mask)
 
         decoder_cross_attention_inputs = [
             decoder_attention_output,
@@ -473,7 +527,7 @@ class TransformerBERT(LegacyLayer):
 
         return layer_output, key, value
 
-    def call(self, inputs, mode = 'encoder', cache_key=None, cache_value=None):
+    def call(self, inputs, mode="encoder", cache_key=None, cache_value=None):
         """
         Args:
             # Scalar dimensions referenced here:
@@ -500,7 +554,9 @@ class TransformerBERT(LegacyLayer):
             outputs = self.call_decoder(inputs, cache_key=cache_key, cache_value=cache_value)
 
         elif self._cross_attention_inside_encoder:
-            outputs = self.call_cross_attention_in_encoder(inputs, mode=mode, cache_key=cache_key, cache_value=cache_value)
+            outputs = self.call_cross_attention_in_encoder(
+                inputs, mode=mode, cache_key=cache_key, cache_value=cache_value
+            )
         else:
             outputs = self.call_training(inputs, cache_key=cache_key, cache_value=cache_value)
         return outputs
