@@ -334,9 +334,7 @@ class TransformerGPT2(LegacyLayer):
         # layer_output = self._output_layer_norm(layer_output + attention_output)
         return layer_output + attention_output, key, value
 
-
-    def call_cross_attention_in_encoder(self,
-            inputs, mode, cache_key=None, cache_value=None):
+    def call_cross_attention_in_encoder(self, inputs, mode, cache_key=None, cache_value=None):
         """
         inputs: dict keys:
                 if self.is_training:
@@ -375,14 +373,18 @@ class TransformerGPT2(LegacyLayer):
         (
             input_tensor,
             attention_mask,
-            decoder_encoder_mask, # None when  mode == 'encoder'
-            encoder_attention_output, # None when mode == 'encoder'
+            decoder_encoder_mask,  # None when  mode == 'encoder'
+            encoder_attention_output,  # None when mode == 'encoder'
         ) = inputs
-        if mode == 'encoder':
+        if mode == "encoder":
             encoder_attention_output, _, _ = calculate_self_attention(input_tensor, attention_mask)
             return encoder_attention_output, _, _
-        if mode == 'decoder':
-            decoder_attention_output, key, value,  = calculate_self_attention(input_tensor, attention_mask)
+        if mode == "decoder":
+            (
+                decoder_attention_output,
+                key,
+                value,
+            ) = calculate_self_attention(input_tensor, attention_mask)
 
         decoder_cross_attention_inputs = [
             decoder_attention_output,
@@ -454,7 +456,7 @@ class TransformerGPT2(LegacyLayer):
             layer_output = tf.cast(layer_output, tf.float16)
         return layer_output + input_tensor, key, value
 
-    def call(self, inputs, mode = 'encoder', cache_key=None, cache_value=None):
+    def call(self, inputs, mode="encoder", cache_key=None, cache_value=None):
         """
         Args:
             # Scalar dimensions referenced here:
@@ -481,7 +483,9 @@ class TransformerGPT2(LegacyLayer):
             outputs = self.call_decoder(inputs, cache_key=cache_key, cache_value=cache_value)
 
         elif self._cross_attention_inside_encoder:
-            outputs = self.call_cross_attention_in_encoder(inputs, mode=mode, cache_key=cache_key, cache_value=cache_value)
+            outputs = self.call_cross_attention_in_encoder(
+                inputs, mode=mode, cache_key=cache_key, cache_value=cache_value
+            )
         else:
             outputs = self.call_training(inputs, cache_key=cache_key, cache_value=cache_value)
-        return outputs
\ No newline at end of file
+        return outputs
