@@ -7,9 +7,10 @@ from absl import logging
 
 from tf_transformers.activations import get_activation
 from tf_transformers.core import LegacyLayer
-from tf_transformers.layers import (GPT2LayerNormalization, OnDeviceEmbedding,
-                             SimplePositionEmbedding)
-from tf_transformers.layers.mask import CausalMask, SelfAttentionMask, prefix_mask
+from tf_transformers.layers import (GPT2LayerNormalization, MLMLayer,
+                                    OnDeviceEmbedding, SimplePositionEmbedding)
+from tf_transformers.layers.mask import (CausalMask, CrossAttentionMask,
+                                         SelfAttentionMask, prefix_mask)
 from tf_transformers.layers.transformer import TransformerGPT2
 
 logging.set_verbosity("INFO")
@@ -38,7 +39,7 @@ class GPT2Encoder(LegacyLayer):
         is_training=None,
         batch_size=None,
         sequence_length=None,
-        use_type_embeddings=True,
+        use_type_embeddings=False,
         use_positonal_embeddings=True,
         pipeline_mode=None,
         is_decoder=False,
@@ -80,7 +81,7 @@ class GPT2Encoder(LegacyLayer):
         self.type_vocab_size = config["type_vocab_size"]
         self.num_hidden_layers = config["num_hidden_layers"]
         self.num_attention_heads = config["num_attention_heads"]
-        self.attention_head_size = config['attention_head_size']
+        self.attention_head_size = config["attention_head_size"]
         self.max_position_embeddings = config["max_position_embeddings"]
         self.intermediate_size = config["intermediate_size"]
         self.embedding_size = config["embedding_size"]
@@ -136,7 +137,7 @@ class GPT2Encoder(LegacyLayer):
             "share_encoder_embeddings": self.share_encoder_embeddings,
             "share_attention_layers": self.share_attention_layers,
             "cross_attention_inside_encoder": cross_attention_inside_encoder,
-            "return_all_layer_token_embeddings": self.return_all_layer_token_embeddings
+            "return_all_layer_token_embeddings": self.return_all_layer_token_embeddings,
         }
 
         # Update config dict with passed config
@@ -151,7 +152,6 @@ class GPT2Encoder(LegacyLayer):
                 self._type_embeddings = encoder_type_embedding_layer
                 self._position_embedding_layer = encoder_positional_embedding_layer
 
-
         # Embedding Norm
         self._embedding_norm = tf.keras.layers.LayerNormalization(
             name="embeddings/layer_norm",
@@ -209,8 +209,6 @@ class GPT2Encoder(LegacyLayer):
         self.model_inputs, self.model_outputs = self.get_model(initialize_only=True)
         logging.info("Initialized Variables")
 
-
-
     def call_predict(self, inputs):
         """Inputs will be pass to this method, when is_training = False.
         The need to cache the past `key` and `value` tensors are \
@@ -330,16 +328,16 @@ class GPT2Encoder(LegacyLayer):
             )
             encoder_outputs.append(embeddings)
 
-        def step_0_gather(past_length):
+        def step_0_gather(past_length, token_embeddings):
             cache_length = tf.reduce_sum(tf.cast(tf.not_equal(input_ids_mod, -1), tf.int32), axis=1) - 1
             # Getting corresponding last token tensor and last token logits
-            last_token_tensor = tf.gather_nd(embeddings, tf.expand_dims(cache_length, axis=1), batch_dims=1)
+            last_token_tensor = tf.gather_nd(token_embeddings, tf.expand_dims(cache_length, axis=1), batch_dims=1)
             past_length = past_length + cache_length
             return past_length, last_token_tensor
 
-        def step_other_gather(past_length):
+        def step_other_gather(past_length, token_embeddings):
             past_length = past_length + sequence_length
-            last_token_tensor = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(encoder_outputs[-1])
+            last_token_tensor = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_embeddings)
             return past_length, last_token_tensor
 
         # batch_size x sequence_length x embedding_size
@@ -351,18 +349,18 @@ class GPT2Encoder(LegacyLayer):
         # the given inputs is the first input
         past_length, last_token_tensor = tf.cond(
             tf.equal(tf.reduce_sum(past_length), 0),
-            lambda: step_0_gather(past_length),
-            lambda: step_other_gather(past_length),
+            lambda: step_0_gather(past_length, token_embeddings),
+            lambda: step_other_gather(past_length, token_embeddings),
         )
 
         # token --> vocab ( batch_size x sequence_length x vocab_size)
-        token_logits = tf.matmul(
-            token_embeddings,
+        last_token_logits = tf.matmul(
+            last_token_tensor,
             self.get_embedding_table(),
             transpose_b=True,
             name="token_logits",
         )
-        last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
+        # last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
 
         # Expand dims of past_length back to 2D
         past_length = tf.expand_dims(past_length, 0, name="past_length")
@@ -372,6 +370,7 @@ class GPT2Encoder(LegacyLayer):
         all_cache_value = tf.stack(all_cache_value, axis=0, name="all_cache_value")
 
         return {
+            "token_embeddings": token_embeddings,
             "last_token_logits": last_token_logits,
             "past_length": past_length,
             "all_cache_key": all_cache_key,
@@ -446,7 +445,7 @@ class GPT2Encoder(LegacyLayer):
             "last_token_logits": last_token_logits,
         }
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = encoder_outputs
+            result["all_layer_token_embeddings"] = encoder_outputs
         return result
 
     def call_cross_attention_encoder(self, inputs):
@@ -514,10 +513,10 @@ class GPT2Encoder(LegacyLayer):
                 [
                     encoder_embeddings,
                     encoder_attention_mask,
-                    decoder_encoder_mask, # dummy decoder_encoder_mask
-                    encoder_embeddings, # dummy encoder_hidden_states
+                    decoder_encoder_mask,  # dummy decoder_encoder_mask
+                    encoder_embeddings,  # dummy encoder_hidden_states
                 ],
-                mode = 'encoder'
+                mode="encoder",
             )
             encoder_outputs.append(encoder_embeddings)
 
@@ -526,13 +525,8 @@ class GPT2Encoder(LegacyLayer):
         for i in range(self.num_hidden_layers):
             layer = self._transformer_layers[i]
             decoder_embeddings, _, _ = layer(
-                [
-                    decoder_embeddings,
-                    decoder_attention_mask,
-                    decoder_encoder_mask,
-                    encoder_hidden_states
-                ],
-                mode = 'decoder'
+                [decoder_embeddings, decoder_attention_mask, decoder_encoder_mask, encoder_hidden_states],
+                mode="decoder",
             )
             decoder_outputs.append(decoder_embeddings)
 
@@ -569,17 +563,16 @@ class GPT2Encoder(LegacyLayer):
 
         last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
 
-        result =  {
+        result = {
             "token_embeddings": token_embeddings,
             "token_logits": token_logits,
             "last_token_logits": last_token_logits,
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = decoder_outputs
+            result["all_layer_token_embeddings"] = decoder_outputs
         return result
 
-
     def call_cross_attention_encoder_predict(self, inputs):
         """[summary]
 
@@ -637,6 +630,7 @@ class GPT2Encoder(LegacyLayer):
                 input_ids ([type]): [description]
                 input_type_ids ([type]): [description]
             """
+
             def step_0_cache_length(_):
                 return tf.constant(0, dtype=tf.int32)
 
@@ -697,7 +691,7 @@ class GPT2Encoder(LegacyLayer):
 
         # Decoder mask is always None
         decoder_attention_mask = CausalMask()(decoder_embeddings)
-        decoder_encoder_mask   = CrossAttentionMask()([decoder_input_ids, encoder_input_mask])
+        decoder_encoder_mask = CrossAttentionMask()([decoder_input_ids, encoder_input_mask])
 
         all_cache_key = [
             tf.squeeze(item, axis=0)
@@ -719,12 +713,12 @@ class GPT2Encoder(LegacyLayer):
                     [
                         encoder_embeddings,
                         encoder_attention_mask,
-                        decoder_encoder_mask, # decoder_encoder_mask
+                        decoder_encoder_mask,  # decoder_encoder_mask
                         encoder_embeddings,
                     ],
-                    mode = 'encoder',
-                cache_key=cache_key,
-                cache_value=cache_value,
+                    mode="encoder",
+                    cache_key=cache_key,
+                    cache_value=cache_value,
                 )
                 encoder_outputs.append(encoder_embeddings)
             encoder_hidden_states = encoder_outputs[-1]
@@ -753,7 +747,7 @@ class GPT2Encoder(LegacyLayer):
                     decoder_encoder_mask,
                     encoder_hidden_states,
                 ],
-                mode = 'decoder',
+                mode="decoder",
                 cache_key=cache_key,
                 cache_value=cache_value,
             )
@@ -807,7 +801,6 @@ class GPT2Encoder(LegacyLayer):
             "last_token_logits": last_token_logits,
         }
 
-
     def call_decoder_predict(self, inputs):
         """Inputs will be pass to this method, when is_training = False and is_decoder = True. # noqa
         The need to cache the past `key` and `value` tensors for decoders \
@@ -988,14 +981,14 @@ class GPT2Encoder(LegacyLayer):
         )
         last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
 
-        return {
+        result = {
             "token_embeddings": token_embeddings,
             "token_logits": token_logits,
             "last_token_logits": last_token_logits,
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = decoder_encoder_mask
+            result["all_layer_token_embeddings"] = decoder_encoder_mask
         return result
 
     def call(self, inputs):
