@@ -2,7 +2,8 @@ import numpy as np
 import tensorflow as tf
 
 from tf_transformers.text import (_gather_beams, _log_prob_from_logits,
-                           assign_zeros_to_K_V, top_k_logits, top_p_logits)
+                                  assign_zeros_to_K_V, top_k_logits,
+                                  top_p_logits)
 
 tf.keras.backend.clear_session()
 
@@ -24,8 +25,8 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
         max_sequence_length=None,
         beam_size=1,
         eos_id=-100,
-        sampling_temperature = 1.0,
-        alpha = 0.0,
+        sampling_temperature=1.0,
+        alpha=0.0,
         do_sample=False,
         top_k=0,
         top_p=0,
@@ -69,8 +70,13 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
 
         self.model = model
 
-        decoder_config = model.model_config['decoder']
-        self.embedding_size, self.decoder_num_attention_heads,self.decoder_num_hidden_layers, self.decoder_attention_state = self.auto_infer_config(decoder_config)
+        decoder_config = model.model_config["decoder"]
+        (
+            self.embedding_size,
+            self.decoder_num_attention_heads,
+            self.decoder_num_hidden_layers,
+            self.decoder_attention_state,
+        ) = self.auto_infer_config(decoder_config)
 
         self.decoder_input_type_ids = decoder_input_type_ids
         # Validate decoder type ids are there
@@ -110,10 +116,13 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
         decoder_model = tf.keras.Model(inputs=self.model_inputs, outputs=layer_outputs, name="decoder_model")
         return decoder_model
 
-    def validate_decoder_type_ids(self,inputs):
+    def validate_decoder_type_ids(self, inputs):
         if "decoder_input_type_ids" in inputs:
             if self.decoder_input_type_ids < 0:
-                raise ValueError("Seems like you model has `decoder_input_type_ids`, but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`")
+                raise ValueError(
+                    "Seems like you model has `decoder_input_type_ids`,\
+                         but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`"
+                )
 
     def auto_infer_config(self, config):
         """[summary]
@@ -124,10 +133,10 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
         Returns:
             [type]: [description]
         """
-        embedding_size = config['embedding_size']
-        decoder_num_attention_heads = config['num_attention_heads']
-        decoder_num_hidden_layers = config['num_hidden_layers']
-        attention_head_size = config['attention_head_size']
+        embedding_size = config["embedding_size"]
+        decoder_num_attention_heads = config["num_attention_heads"]
+        decoder_num_hidden_layers = config["num_hidden_layers"]
+        attention_head_size = config["attention_head_size"]
         return (embedding_size, decoder_num_attention_heads, decoder_num_hidden_layers, attention_head_size)
 
     def get_inputs(self):
@@ -267,7 +276,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
 
             model_outputs = self.model(inputs)
             model_logits = model_outputs["last_token_logits"]
-            model_logits = model_logits/self.temperature
+            model_logits = model_logits / self.temperature
 
             if self.do_sample:
                 prediction_ids = tf.random.categorical(model_logits, num_samples=1)
@@ -318,7 +327,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             model_inputs = {}
             for input_key, input_value in inputs.items():
                 # We dont want iterations in model_inputs
-                if input_key == 'iterations':
+                if input_key == "iterations":
                     continue
                 model_inputs[input_key] = input_value
             # Prepare inputs
@@ -356,11 +365,13 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             model_inputs["decoder_input_ids"] = decoder_input_ids
 
             if "decoder_input_type_ids" in self.decoder_input_name_list:
-                model_inputs["decoder_input_type_ids"] = tf.ones_like(model_inputs['decoder_input_ids']) * self.decoder_input_type_ids
+                model_inputs["decoder_input_type_ids"] = (
+                    tf.ones_like(model_inputs["decoder_input_ids"]) * self.decoder_input_type_ids
+                )
 
             model_outputs = self.model(model_inputs)
             model_logits = model_outputs["last_token_logits"]
-            model_logits = model_logits/self.temperature
+            model_logits = model_logits / self.temperature
 
             if self.do_sample:
                 prediction_ids = tf.random.categorical(model_logits, num_samples=1)
@@ -531,7 +542,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             model_outputs = self.model(inputs)
 
             model_logits = model_outputs["last_token_logits"]
-            model_logits = model_logits/self.temperature
+            model_logits = model_logits / self.temperature
 
             all_cache_key = model_outputs["decoder_all_cache_key"]
             all_cache_value = model_outputs["decoder_all_cache_value"]
@@ -558,7 +569,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             log_probs = candidate_log_probs + tf.expand_dims(alive_log_probs, axis=2)
 
             # Add length penalty
-            length_penalty = tf.pow(((5. + (tf.cast(i, tf.float32) + 1.0)) / 6.), self.alpha)
+            length_penalty = tf.pow(((5.0 + (tf.cast(i, tf.float32) + 1.0)) / 6.0), self.alpha)
             log_probs = log_probs / length_penalty
 
             # Each batch item has beam_size * vocab_size candidate sequences. For each
@@ -582,7 +593,9 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
                 topk_log_probs = next_scores
                 topk_indices = next_tokens
             else:
-                topk_log_probs, topk_indices = tf.nn.top_k(flat_log_probs, k=beams_to_keep) # (batch_size x k (beams_to_keep))
+                topk_log_probs, topk_indices = tf.nn.top_k(
+                    flat_log_probs, k=beams_to_keep
+                )  # (batch_size x k (beams_to_keep))
 
             topk_beam_indices = topk_indices // vocab_size
             topk_seq, coordinates = _gather_beams(alive_seq, topk_beam_indices, batch_size, beams_to_keep)
@@ -646,7 +659,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             model_inputs = {}
             for input_key, input_value in inputs.items():
                 # We dont want iterations in model_inputs
-                if input_key == 'iterations':
+                if input_key == "iterations":
                     continue
                 model_inputs[input_key] = tf.repeat(input_value, [self.beam_size], axis=0)
 
@@ -696,7 +709,9 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             model_inputs["decoder_input_ids"] = decoder_input_ids
 
             if "decoder_input_type_ids" in self.decoder_input_name_list:
-                model_inputs["decoder_input_type_ids"] = tf.ones_like(model_inputs['decoder_input_ids']) * self.decoder_input_type_ids
+                model_inputs["decoder_input_type_ids"] = (
+                    tf.ones_like(model_inputs["decoder_input_ids"]) * self.decoder_input_type_ids
+                )
 
             # We need this to re-ordering and keep track of best -log(prob))
             alive_log_probs = -np.inf * tf.ones((batch_size, self.beam_size - 1))
@@ -706,7 +721,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             # First pass to the model
             model_outputs = self.model(model_inputs)
             model_logits = model_outputs["last_token_logits"]
-            model_logits = model_logits/self.temperature
+            model_logits = model_logits / self.temperature
 
             # Update iter
             i = i + 1
@@ -736,7 +751,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             log_probs = candidate_log_probs + tf.expand_dims(alive_log_probs, axis=2)
 
             # Add length penalty
-            length_penalty = tf.pow(((5. + (tf.cast(i, tf.float32) + 1.0)) / 6.), self.alpha)
+            length_penalty = tf.pow(((5.0 + (tf.cast(i, tf.float32) + 1.0)) / 6.0), self.alpha)
             log_probs = log_probs / length_penalty
 
             # Each batch item has beam_size * vocab_size candidate sequences. For each
@@ -946,7 +961,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
 
             model_outputs = self.model(inputs)
             model_logits = model_outputs["last_token_logits"]
-            model_logits = model_logits/self.temperature
+            model_logits = model_logits / self.temperature
 
             if self.top_k > 0:
                 model_logits = top_k_logits(model_logits, k=self.top_k)
@@ -1003,7 +1018,7 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
 
             model_inputs = {}
             for input_key, input_value in inputs.items():
-                if input_key == 'iterations':
+                if input_key == "iterations":
                     continue
                 model_inputs[input_key] = tf.repeat(input_value, [self.num_return_sequences], axis=0)
 
@@ -1048,12 +1063,14 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             model_inputs["decoder_input_ids"] = decoder_input_ids
 
             if "decoder_input_type_ids" in self.decoder_input_name_list:
-                model_inputs["decoder_input_type_ids"] = tf.ones_like(model_inputs['decoder_input_ids']) * self.decoder_input_type_ids
+                model_inputs["decoder_input_type_ids"] = (
+                    tf.ones_like(model_inputs["decoder_input_ids"]) * self.decoder_input_type_ids
+                )
 
             # First pass to the model
             model_outputs = self.model(model_inputs)
             model_logits = model_outputs["last_token_logits"]
-            model_logits = model_logits/self.temperature
+            model_logits = model_logits / self.temperature
 
             if self.top_k > 0:
                 model_logits = top_k_logits(model_logits, k=self.top_k)
@@ -1150,10 +1167,13 @@ class TextDecoderSerializableSeq2Seq(tf.keras.layers.Layer):
             results_dict["input_ids"] = input_ids_orig
             # Skip -1 initial ids
             results_dict["predicted_ids"] = results[-1][:, 1:]
-            results_dict["predicted_ids"] = tf.cast(tf.reshape(
-                results_dict["predicted_ids"],
-                (batch_size, self.num_return_sequences, -1),
-            ), tf.int32)
+            results_dict["predicted_ids"] = tf.cast(
+                tf.reshape(
+                    results_dict["predicted_ids"],
+                    (batch_size, self.num_return_sequences, -1),
+                ),
+                tf.int32,
+            )
 
             matched_positions = (
                 tf.squeeze(
