@@ -2,7 +2,8 @@ import numpy as np
 import tensorflow as tf
 
 from tf_transformers.text import (_gather_beams, _log_prob_from_logits,
-                           assign_zeros_to_K_V, top_k_logits, top_p_logits)
+                                  assign_zeros_to_K_V, top_k_logits,
+                                  top_p_logits)
 
 tf.keras.backend.clear_session()
 
@@ -16,8 +17,8 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
     def __init__(
         self,
         model,
-        max_iterations,
         mode,
+        max_iterations=None,
         batch_size=None,
         sequence_length=None,
         max_sequence_length=None,
@@ -70,7 +71,12 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
         self.model = model
 
         model_config = model.model_config
-        self.embedding_size, self.num_attention_heads,self.num_hidden_layers, self.attention_state  = self.auto_infer_config(model_config)
+        (
+            self.embedding_size,
+            self.num_attention_heads,
+            self.num_hidden_layers,
+            self.attention_state,
+        ) = self.auto_infer_config(model_config)
 
         self.input_type_ids = input_type_ids
         self.input_mask_ids = input_mask_ids
@@ -100,10 +106,13 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
         elif self.mode == "top_k_top_p":
             self.decoder_fn = self.top_k_top()
 
-    def validate_decoder_type_ids(self,inputs):
+    def validate_decoder_type_ids(self, inputs):
         if "input_type_ids" in inputs:
             if self.input_type_ids < 0:
-                raise ValueError("Seems like you model has `decoder_input_type_ids`, but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`")
+                raise ValueError(
+                    "Seems like you model has `decoder_input_type_ids`,\
+                         but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`"
+                )
 
     def auto_infer_config(self, config, saved_model=False):
         """[summary]
@@ -115,16 +124,16 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             [type]: [description]
         """
         if saved_model:
-            embedding_size = config['embedding_size'].numpy()
-            num_attention_heads = config['num_attention_heads'].numpy()
-            num_hidden_layers = config['num_hidden_layers'].numpy()
-            attention_head_size = config['attention_head_size'].numpy()
+            embedding_size = config["embedding_size"].numpy()
+            num_attention_heads = config["num_attention_heads"].numpy()
+            num_hidden_layers = config["num_hidden_layers"].numpy()
+            attention_head_size = config["attention_head_size"].numpy()
             return (embedding_size, num_attention_heads, num_hidden_layers, attention_head_size)
         else:
-            embedding_size = config['embedding_size']
-            num_attention_heads = config['num_attention_heads']
-            num_hidden_layers = config['num_hidden_layers']
-            attention_head_size = config['attention_head_size']
+            embedding_size = config["embedding_size"]
+            num_attention_heads = config["num_attention_heads"]
+            num_hidden_layers = config["num_hidden_layers"]
+            attention_head_size = config["attention_head_size"]
             return (embedding_size, num_attention_heads, num_hidden_layers, attention_head_size)
 
     def get_model(self):
@@ -296,7 +305,7 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             # Repeat for beam search (We nedd batch_size x beam_size)
             model_inputs = {}
             for input_key, input_value in inputs.items():
-                if input_key == 'iterations':
+                if input_key == "iterations":
                     continue
                 model_inputs[input_key] = input_value
 
@@ -330,13 +339,13 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             model_inputs["past_length"] = past_length
 
             if "input_type_ids" in self.input_name_list:
-                model_inputs["input_type_ids"] = tf.ones_like(model_inputs['input_ids']) * self.input_type_ids
+                model_inputs["input_type_ids"] = tf.ones_like(model_inputs["input_ids"]) * self.input_type_ids
 
             if "input_mask" in self.input_name_list:
-                model_inputs["input_mask"] = tf.ones_like(model_inputs['input_ids']) * self.input_mask_ids
+                model_inputs["input_mask"] = tf.ones_like(model_inputs["input_ids"]) * self.input_mask_ids
 
             model_outputs = self.model(model_inputs)
-            model_logits = model_outputs["last_token_logits"]/self.temperature
+            model_logits = model_outputs["last_token_logits"] / self.temperature
             if self.do_sample:
                 prediction_ids = tf.random.categorical(model_logits, num_samples=1)
                 input_ids = tf.cast(prediction_ids, tf.int32)
@@ -518,7 +527,7 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             log_probs = candidate_log_probs + tf.expand_dims(alive_log_probs, axis=2)
 
             # Add length penalty
-            length_penalty = tf.pow(((5. + (tf.cast(i, tf.float32) + 1.0)) / 6.), self.alpha)
+            length_penalty = tf.pow(((5.0 + (tf.cast(i, tf.float32) + 1.0)) / 6.0), self.alpha)
             log_probs = log_probs / length_penalty
 
             # Each batch item has beam_size * vocab_size candidate sequences. For each
@@ -604,7 +613,7 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             # Repeat for beam search (We nedd batch_size x beam_size)
             model_inputs = {}
             for input_key, input_value in inputs.items():
-                if input_key == 'iterations':
+                if input_key == "iterations":
                     continue
                 model_inputs[input_key] = tf.repeat(input_value, [self.beam_size], axis=0)
             # New batch size
@@ -638,10 +647,10 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             model_inputs["past_length"] = past_length
 
             if "input_type_ids" in self.input_name_list:
-                model_inputs["input_type_ids"] = tf.ones_like(model_inputs['input_ids']) * self.input_type_ids
+                model_inputs["input_type_ids"] = tf.ones_like(model_inputs["input_ids"]) * self.input_type_ids
 
             if "input_mask" in self.input_name_list:
-                model_inputs["input_mask"] = tf.ones_like(model_inputs['input_ids']) * self.input_mask_ids
+                model_inputs["input_mask"] = tf.ones_like(model_inputs["input_ids"]) * self.input_mask_ids
 
             # We need this to re-ordering and keep track of best -log(prob))
             alive_log_probs = -np.inf * tf.ones((batch_size, self.beam_size - 1))
@@ -679,7 +688,7 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             log_probs = candidate_log_probs + tf.expand_dims(alive_log_probs, axis=2)
 
             # Add length penalty
-            length_penalty = tf.pow(((5. + (tf.cast(i, tf.float32) + 1.0)) / 6.), self.alpha)
+            length_penalty = tf.pow(((5.0 + (tf.cast(i, tf.float32) + 1.0)) / 6.0), self.alpha)
             log_probs = log_probs / length_penalty
 
             # Each batch item has beam_size * vocab_size candidate sequences. For each
@@ -911,7 +920,7 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
 
             model_inputs = {}
             for input_key, input_value in inputs.items():
-                if input_key == 'iterations':
+                if input_key == "iterations":
                     continue
                 model_inputs[input_key] = tf.repeat(input_value, [self.num_return_sequences], axis=0)
             # Updated batch size
@@ -941,10 +950,10 @@ class TextDecoderSerializable(tf.keras.layers.Layer):
             model_inputs["past_length"] = past_length
 
             if "input_type_ids" in self.input_name_list:
-                model_inputs["input_type_ids"] = tf.ones_like(model_inputs['input_ids']) * self.input_type_ids
+                model_inputs["input_type_ids"] = tf.ones_like(model_inputs["input_ids"]) * self.input_type_ids
 
             if "input_mask" in self.input_name_list:
-                model_inputs["input_mask"] = tf.ones_like(model_inputs['input_ids']) * self.input_mask_ids
+                model_inputs["input_mask"] = tf.ones_like(model_inputs["input_ids"]) * self.input_mask_ids
 
             # First pass to the model
             model_outputs = self.model(model_inputs)
